chop.image — chop documentation

# chop.image

## Image utilities.

Utility functions for image manipulation and visualization.

Functions

`group_patches`([x_patch_size, y_patch_size, …]) |
`matplotlib_imshow`(img[, one_channel, ax]) |
`matplotlib_imshow_batch`(batch[, labels, …]) |
`normalize_image`(img[, range, one_channel]) | Linearly normalizes an image to be in range.

`chop.image.` `normalize_image`(img, range=0.0, 1.0, one_channel=False)

  Linearly normalizes an image to be in range.

  Supposes that img is in numpy image shape: (m, n, channels) or (m, n)